==> refcomp-client-1.3-sources.jar: fr/inra/refcomp/client/user/SearchResults.java <==
/*
 * #%L
 * Refcomp :: GWT client
 * 
 * $Id: SearchResults.java 164 2011-05-13 13:12:11Z jcouteau $
 * $HeadURL: svn+ssh://jcouteau@scm.mulcyber.toulouse.inra.fr/svnroot/refcomp/tags/refcomp-1.3/refcomp-client/src/main/java/fr/inra/refcomp/client/user/SearchResults.java $
 * %%
 * Copyright (C) 2010 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.client.user;

import com.google.gwt.core.client.GWT;
import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.http.client.URL;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.uibinder.client.UiTemplate;
import com.google.gwt.user.client.History;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.InlineLabel;
import com.google.gwt.user.client.ui.Panel;
import com.google.gwt.user.client.ui.RootPanel;
import fr.inra.refcomp.client.RefComp;
import fr.inra.refcomp.client.constants.CSS;
import fr.inra.refcomp.client.constants.RefcompMessages;
import fr.inra.refcomp.client.constants.Unauthorized;
import fr.inra.refcomp.client.services.StorageService;
import fr.inra.refcomp.client.services.StorageServiceAsync;
import fr.inra.refcomp.entities.Agent;
import fr.inra.refcomp.entities.AgentSkill;
import fr.inra.refcomp.entities.EntitiesList;
import fr.inra.refcomp.entities.Frequency;
import fr.inra.refcomp.entities.Skill;
import java.util.List;
import org.nuiton.web.gwt.comparable.ComparableAnchor;
import org.nuiton.web.gwt.misc.LoaderNotification;
import org.nuiton.web.gwt.table.DefaultTableModel;
import org.nuiton.web.gwt.table.SortableFlexTableWithModel;
import org.nuiton.web.gwt.table.SortableTableModel;
import org.nuiton.wikitty.entities.BusinessEntity;

/**
 * User: couteau
 * Date: 3 nov. 2010
 */
public class SearchResults extends Composite {

    public static final int NAME_COL = 0;
    public static int TECH_SKILL_COL = 1;
    public static int FREQUENCY_COL = 2;
    public static int COMMENT_COL = 3;

    @UiTemplate("SearchResults.ui.xml")
    interface MyUiBinder extends UiBinder<Panel, SearchResults> {
    }

    private static final MyUiBinder binder = GWT.create(MyUiBinder.class);

    @UiField
    SortableFlexTableWithModel resultsTable;

    @UiField
    InlineLabel searchField;

    protected DefaultTableModel model;

    public SearchResults() {
        initWidget(binder.createAndBindUi(this));

        StorageServiceAsync service = GWT.create(StorageService.class);

        service.isLoggedIn(new AsyncCallback<Boolean>() {
            @Override
            public void onFailure(Throwable throwable) {
                RefComp.logOut();
                RootPanel content = RootPanel.get("content");
                content.clear();
                content.add(new Unauthorized());
                LoaderNotification.closeLoader();
            }

            @Override
            public void onSuccess(Boolean isLoggedIn) {
                if (!isLoggedIn) {
                    RefComp.logOut();
                    RootPanel content = RootPanel.get("content");
                    content.clear();
                    content.add(new Unauthorized());
                    LoaderNotification.closeLoader();
                } else {

                    SortableTableModel sortableModel = new SortableTableModel(model);

                    resultsTable.setModel(sortableModel);
                }
            }
        });
    }

    public SearchResults(final String searchString, final EntitiesList results)
    {
        initWidget(binder.createAndBindUi(this));

        StorageServiceAsync service = GWT.create(StorageService.class);

        service.isLoggedIn(new AsyncCallback<Boolean>() {
            @Override
            public void onFailure(Throwable throwable) {
                RefComp.logOut();
                RootPanel content = RootPanel.get("content");
                content.clear();
                content.add(new Unauthorized());
                LoaderNotification.closeLoader();
            }

            @Override
            public void onSuccess(Boolean isLoggedIn) {
                if (!isLoggedIn) {
                    RefComp.logOut();
                    RootPanel content = RootPanel.get("content");
                    content.clear();
                    content.add(new Unauthorized());
                    LoaderNotification.closeLoader();
                } else {

                    RefcompMessages messages = GWT.create(RefcompMessages.class);

                    Object[][] data = new Object[][]{};

                    String[] columns = {
                            messages.agentName(),
                            messages.skill(),
                            messages.frequency(),
                            messages.comment()};

                    model = new DefaultTableModel(data, columns);

                    SortableTableModel sortableModel = new SortableTableModel(model);

                    resultsTable.setModel(sortableModel);

                    if (searchString != null) {
                        searchField.setText(URL.decodeQueryString(searchString));
                    }

                    List<BusinessEntity> skills = results.getEntities();

                    if (skills.size() > 0) {
                        for (int i = 0; i < columns.length; i++) {
                            resultsTable.setText(0, i, columns[i]);
                            resultsTable.getRowFormatter().addStyleName(0, CSS.TABLE_HEADER);
                            resultsTable.getCellFormatter().setStyleName(0, i, CSS.SORTABLE);
                        }

                        for (BusinessEntity entity : skills) {
                            AgentSkill skill = (AgentSkill) entity;
                            addRow(skill, results);
                        }
                    } else {
                        resultsTable.setVisible(false);
                    }

                    sortableModel.setSortedColumn(NAME_COL, SortableTableModel.ASC);

                    LoaderNotification.closeLoader();
                }
            }
        });

    }

    protected void addRow(final AgentSkill skill, EntitiesList dependencies) {
        int columnCount = model.getColumnCount();

        Object[] row = new Object[columnCount];

        // If the skill returned does not have an agent, it means it is an old
        // damaged data. Do not display it.
        if (skill.getAgent() == null) {
            return;
        }

        //Name
        final Agent agent = (Agent) dependencies.getDependency(skill.getAgent());

        if (agent != null) {
            ComparableAnchor nameLink = new ComparableAnchor(agent.getLastName() + " " +
                    agent.getFirstName());
            nameLink.addClickHandler(new ClickHandler() {
                @Override
                public void onClick(ClickEvent event) {
                    History.newItem("agentSheet?agent=" + agent.getWikittyId());
                }
            });
            row[NAME_COL] = nameLink;
        }

        //Tech skill
        Skill techSkill = (Skill) dependencies.getDependency(skill.getTechnicalSkill());
        if (techSkill != null) {
            row[TECH_SKILL_COL] = techSkill.getName();
        }

        //Frequency
        Frequency frequency = (Frequency) dependencies.getDependency(skill.getFrequency());
        if (frequency != null) {
            row[FREQUENCY_COL] = frequency.getName();
        }

        //comment
        row[COMMENT_COL] = skill.getComment();

        model.addRow(row);
    }
}

==> refcomp-client-1.5-sources.jar: fr/inra/refcomp/client/user/SearchResults.java <==
/*
 * #%L
 * Refcomp :: GWT client
 * 
 * $Id: SearchResults.java 235 2011-09-21 10:34:48Z jcouteau $
 * $HeadURL: svn+ssh://jcouteau@scm.mulcyber.toulouse.inra.fr/svnroot/refcomp/tags/refcomp-1.5.1/refcomp-client/src/main/java/fr/inra/refcomp/client/user/SearchResults.java $
 * %%
 * Copyright (C) 2010 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.client.user;

import com.google.gwt.core.client.GWT;
import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.http.client.URL;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.uibinder.client.UiTemplate;
import com.google.gwt.user.client.History;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.InlineLabel;
import com.google.gwt.user.client.ui.Panel;
import com.google.gwt.user.client.ui.RootPanel;
import fr.inra.refcomp.client.RefComp;
import fr.inra.refcomp.client.constants.CSS;
import fr.inra.refcomp.client.constants.RefcompMessages;
import fr.inra.refcomp.client.constants.Unauthorized;
import fr.inra.refcomp.client.services.StorageService;
import fr.inra.refcomp.client.services.StorageServiceAsync;
import fr.inra.refcomp.entities.Agent;
import fr.inra.refcomp.entities.AgentSkill;
import fr.inra.refcomp.entities.EntitiesList;
import fr.inra.refcomp.entities.Frequency;
import fr.inra.refcomp.entities.Skill;
import java.util.Map;
import org.nuiton.web.gwt.comparable.ComparableAnchor;
import org.nuiton.web.gwt.misc.LoaderNotification;
import org.nuiton.web.gwt.table.DefaultTableModel;
import org.nuiton.web.gwt.table.SortableFlexTableWithModel;
import org.nuiton.web.gwt.table.SortableTableModel;
import org.nuiton.wikitty.entities.BusinessEntity;

/**
 * User: couteau
 * Date: 3 nov. 2010
 */
public class SearchResults extends Composite {

    public static final int NAME_COL = 0;
    public static int TECH_SKILL_COL = 1;
    public static int FREQUENCY_COL = 2;
    public static int COMMENT_COL = 3;

    @UiTemplate("SearchResults.ui.xml")
    interface MyUiBinder extends UiBinder<Panel, SearchResults> {
    }

    private static final MyUiBinder binder = GWT.create(MyUiBinder.class);

    @UiField
    SortableFlexTableWithModel resultsTable;

    @UiField
    InlineLabel searchField;

    protected DefaultTableModel model;

    public SearchResults() {
        initWidget(binder.createAndBindUi(this));

        StorageServiceAsync service = GWT.create(StorageService.class);

        service.isLoggedIn(new AsyncCallback<Boolean>() {
            @Override
            public void onFailure(Throwable throwable) {
                RefComp.logOut();
                RootPanel content = RootPanel.get("content");
                content.clear();
                content.add(new Unauthorized());
                LoaderNotification.closeLoader();
            }

            @Override
            public void onSuccess(Boolean isLoggedIn) {
                if (!isLoggedIn) {
                    RefComp.logOut();
                    RootPanel content = RootPanel.get("content");
                    content.clear();
                    content.add(new Unauthorized());
                    LoaderNotification.closeLoader();
                } else {

                    SortableTableModel sortableModel = new SortableTableModel(model);

                    resultsTable.setModel(sortableModel);
                }
            }
        });
    }

    public SearchResults(final String searchString, final EntitiesList results)
    {
        initWidget(binder.createAndBindUi(this));

        StorageServiceAsync service = GWT.create(StorageService.class);

        service.isLoggedIn(new AsyncCallback<Boolean>() {
            @Override
            public void onFailure(Throwable throwable) {
                RefComp.logOut();
                RootPanel content = RootPanel.get("content");
                content.clear();
                content.add(new Unauthorized());
                LoaderNotification.closeLoader();
            }

            @Override
            public void onSuccess(Boolean isLoggedIn) {
                if (!isLoggedIn) {
                    RefComp.logOut();
                    RootPanel content = RootPanel.get("content");
                    content.clear();
                    content.add(new Unauthorized());
                    LoaderNotification.closeLoader();
                } else {

                    RefcompMessages messages = GWT.create(RefcompMessages.class);

                    Object[][] data = new Object[][]{};

                    String[] columns = {
                            messages.agentName(),
                            messages.skill(),
                            messages.frequency(),
                            messages.comment()};

                    model = new DefaultTableModel(data, columns);

                    SortableTableModel sortableModel = new SortableTableModel(model);

                    if (searchString != null) {
                        searchField.setText(URL.decodeQueryString(searchString));
                    }

                    Map<BusinessEntity,Skill> skills = results.getEntities();

                    if (skills.size() > 0) {
                        for (Map.Entry<BusinessEntity, Skill> entry : skills.entrySet()) {
                            AgentSkill skill = (AgentSkill) entry.getKey();
                            addRow(skill, results);
                        }

                        resultsTable.setModel(sortableModel);
                        
                        for (int i = 0; i < columns.length; i++) {
                            resultsTable.setText(0, i, columns[i]);
                            resultsTable.getRowFormatter().addStyleName(0, CSS.TABLE_HEADER);
                            resultsTable.getCellFormatter().setStyleName(0, i, CSS.SORTABLE);
                        }

                    } else {
                        resultsTable.setVisible(false);
                    }

                    sortableModel.setSortedColumn(NAME_COL, SortableTableModel.ASC);

                    LoaderNotification.closeLoader();
                }
            }
        });

    }

    protected void addRow(final AgentSkill skill, EntitiesList dependencies) {
        int columnCount = model.getColumnCount();

        Object[] row = new Object[columnCount];

        // If the skill returned does not have an agent, it means it is an old
        // damaged data. Do not display it.
        if (skill.getAgent() == null) {
            return;
        }

        //Name
        final Agent agent = (Agent) dependencies.getDependency(skill.getAgent());

        if (agent != null) {
            ComparableAnchor nameLink = new ComparableAnchor(agent.getLastName() + " " +
                    agent.getFirstName());
            nameLink.addClickHandler(new ClickHandler() {
                @Override
                public void onClick(ClickEvent event) {
                    History.newItem("agentSheet?agent=" + agent.getWikittyId());
                }
            });
            row[NAME_COL] = nameLink;
        }

        //Tech skill
        Skill techSkill = (Skill) dependencies.getDependency(skill.getTechnicalSkill());
        if (techSkill != null) {
            row[TECH_SKILL_COL] = techSkill.getName();
        }

        //Frequency
        Frequency frequency = (Frequency) dependencies.getDependency(skill.getFrequency());
        if (frequency != null) {
            row[FREQUENCY_COL] = frequency.getName();
        }

        //comment
        row[COMMENT_COL] = skill.getComment();

        model.addRow(row);
    }
}
